// Flutter Packages
import 'package:flutter/material.dart';

// Data Models
import '../../models/view_type.dart';
import '../../models/wrap_options.dart';

// Widgets
import '../defaults/bottom_loader.dart';
import 'grid_pagination.dart';
import 'list_pagination.dart';
import 'wrap_pagination.dart';

class BuildPagination<T> extends StatelessWidget {
  const BuildPagination({
    Key? key,
    required this.controller,
    required this.items,
    required this.itemBuilder,
    required this.isLoading,
    this.gridDelegate = const SliverGridDelegateWithFixedCrossAxisCount(
      crossAxisCount: 2,
      childAspectRatio: 1,
    ),
    this.viewType = ViewType.list,
    this.bottomLoader = const BottomLoader(),
    this.wrapOptions = const WrapOptions(),
  }) : super(key: key);

  final ViewType viewType;
  final ScrollController controller;
  final List<T> items;
  final Widget Function(BuildContext, T, int) itemBuilder;
  final bool isLoading;
  final SliverGridDelegate gridDelegate;
  final Widget bottomLoader;
  final WrapOptions wrapOptions;

  @override
  Widget build(BuildContext context) {
    switch (viewType) {
      case ViewType.list:
        return ListPagination(
          controller: controller,
          items: items,
          itemBuilder: itemBuilder,
          isLoading: isLoading,
          bottomLoader: bottomLoader,
        );
      case ViewType.grid:
        return GridPagination(
          controller: controller,
          items: items,
          itemBuilder: itemBuilder,
          isLoading: isLoading,
          bottomLoader: bottomLoader,
          gridDelegate: gridDelegate,
        );
      case ViewType.wrap:
        return WrapPagination(
          controller: controller,
          items: items,
          itemBuilder: itemBuilder,
          isLoading: isLoading,
          bottomLoader: bottomLoader,
          wrapOptions: wrapOptions,
        );
    }
  }
}
