// Flutter Packages
import 'package:flutter/material.dart';

// Data Models
import '../../models/wrap_options.dart';

class WrapPagination<T> extends StatelessWidget {
  const WrapPagination({
    Key? key,
    required this.controller,
    required this.items,
    required this.itemBuilder,
    required this.isLoading,
    required this.bottomLoader,
    this.wrapOptions = const WrapOptions(),
  }) : super(key: key);

  final ScrollController controller;
  final List<T> items;
  final Widget Function(BuildContext, T, int) itemBuilder;
  final bool isLoading;
  final WrapOptions wrapOptions;
  final Widget bottomLoader;

  @override
  Widget build(BuildContext context) {
    return SingleChildScrollView(
      controller: controller,
      child: Wrap(
        direction: wrapOptions.direction,
        alignment: wrapOptions.alignment,
        spacing: wrapOptions.spacing,
        runAlignment: wrapOptions.runAlignment,
        runSpacing: wrapOptions.runSpacing,
        crossAxisAlignment: wrapOptions.crossAxisAlignment,
        textDirection: wrapOptions.textDirection,
        verticalDirection: wrapOptions.verticalDirection,
        clipBehavior: wrapOptions.clipBehavior,
        children: List.generate(
          items.length + (isLoading ? 1 : 0),
          (int index) {
            if (index >= items.length) return bottomLoader;

            return itemBuilder(context, items[index], index);
          },
        ),
      ),
    );
  }
}
